@@ -21,6 +21,12 @@ from gcloud.aio.taskqueue.utils import decode
 log = logging.getLogger(__name__)
 
 
+def log_future_exception(fut):
+    e = fut.exception()
+    if e:
+        log.exception(e)
+
+
 class LeaseManager:
     def __init__(self, event, executor, headers, task, lease_seconds):
         # pylint: disable=too-many-arguments
@@ -149,7 +155,8 @@ class TaskManager:
             log.info('grabbed %d tasks', len(tasks))
 
             for task in tasks:
-                asyncio.ensure_future(self.process(task))
+                f = asyncio.ensure_future(self.process(task))
+                f.add_done_callback(log_future_exception)
 
     async def process(self, task):
         name = task['name']
@@ -166,10 +173,11 @@ class TaskManager:
         # and at this point I'm sick of having to update the blacklist. If we
         # get an exception while creating a LeaseManager, that's enough for me
         # to be reasonably sure the pool is broken without needing proof.
-        except (concurrent.futures.process.BrokenProcessPool, Exception) as e:  # pylint: disable=broad-except
+        except Exception as e:  # pylint: disable=broad-except
             log.error('process pool broke, quitting TaskManager')
             log.exception(e)
             self.running = False
+            return
 
         try:
             async with self.semaphore:
